==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/servicefabricmesh/kotlin/inputs/HttpRouteMatchPathArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicefabricmesh.kotlin.inputs

import com.pulumi.azurenative.servicefabricmesh.inputs.HttpRouteMatchPathArgs.builder
import com.pulumi.azurenative.servicefabricmesh.kotlin.enums.PathMatchType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Path to match for routing.
 * @property rewrite replacement string for matched part of the Uri.
 * @property type how to match value in the Uri
 * @property value Uri path to match for request.
 */
public data class HttpRouteMatchPathArgs(
    public val rewrite: Output<String>? = null,
    public val type: Output<Either<String, PathMatchType>>,
    public val `value`: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.servicefabricmesh.inputs.HttpRouteMatchPathArgs> {
    override fun toJava(): com.pulumi.azurenative.servicefabricmesh.inputs.HttpRouteMatchPathArgs =
        com.pulumi.azurenative.servicefabricmesh.inputs.HttpRouteMatchPathArgs.builder()
            .rewrite(rewrite?.applyValue({ args0 -> args0 }))
            .type(
                type.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [HttpRouteMatchPathArgs].
 */
@PulumiTagMarker
public class HttpRouteMatchPathArgsBuilder internal constructor() {
    private var rewrite: Output<String>? = null

    private var type: Output<Either<String, PathMatchType>>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value replacement string for matched part of the Uri.
     */
    @JvmName("sdixufccfoomattq")
    public suspend fun rewrite(`value`: Output<String>) {
        this.rewrite = value
    }

    /**
     * @param value how to match value in the Uri
     */
    @JvmName("ivokrwaepiyonlho")
    public suspend fun type(`value`: Output<Either<String, PathMatchType>>) {
        this.type = value
    }

    /**
     * @param value Uri path to match for request.
     */
    @JvmName("ynesoooxwocqxywe")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value replacement string for matched part of the Uri.
     */
    @JvmName("veynkkogxoflbdpw")
    public suspend fun rewrite(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rewrite = mapped
    }

    /**
     * @param value how to match value in the Uri
     */
    @JvmName("hfslskoxchgynnjf")
    public suspend fun type(`value`: Either<String, PathMatchType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value how to match value in the Uri
     */
    @JvmName("cubxxjlntmttexvr")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, PathMatchType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value how to match value in the Uri
     */
    @JvmName("lyrjbflbkvhiuqmt")
    public fun type(`value`: PathMatchType) {
        val toBeMapped = Either.ofRight<String, PathMatchType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Uri path to match for request.
     */
    @JvmName("hlpweaibydutboak")
    public suspend fun `value`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): HttpRouteMatchPathArgs = HttpRouteMatchPathArgs(
        rewrite = rewrite,
        type = type ?: throw PulumiNullFieldException("type"),
        `value` = `value` ?: throw PulumiNullFieldException("value"),
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/servicefabricmesh/kotlin/inputs/HttpRouteMatchPathArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.servicefabricmesh.kotlin.inputs

import com.pulumi.azurenative.servicefabricmesh.inputs.HttpRouteMatchPathArgs.builder
import com.pulumi.azurenative.servicefabricmesh.kotlin.enums.PathMatchType
import com.pulumi.core.Either
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Path to match for routing.
 * @property rewrite replacement string for matched part of the Uri.
 * @property type how to match value in the Uri
 * @property value Uri path to match for request.
 */
public data class HttpRouteMatchPathArgs(
    public val rewrite: Output<String>? = null,
    public val type: Output<Either<String, PathMatchType>>,
    public val `value`: Output<String>,
) : ConvertibleToJava<com.pulumi.azurenative.servicefabricmesh.inputs.HttpRouteMatchPathArgs> {
    override fun toJava(): com.pulumi.azurenative.servicefabricmesh.inputs.HttpRouteMatchPathArgs =
        com.pulumi.azurenative.servicefabricmesh.inputs.HttpRouteMatchPathArgs.builder()
            .rewrite(rewrite?.applyValue({ args0 -> args0 }))
            .type(
                type.applyValue({ args0 ->
                    args0.transform({ args0 -> args0 }, { args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .`value`(`value`.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [HttpRouteMatchPathArgs].
 */
@PulumiTagMarker
public class HttpRouteMatchPathArgsBuilder internal constructor() {
    private var rewrite: Output<String>? = null

    private var type: Output<Either<String, PathMatchType>>? = null

    private var `value`: Output<String>? = null

    /**
     * @param value replacement string for matched part of the Uri.
     */
    @JvmName("bqgmvbtgikffwfvl")
    public suspend fun rewrite(`value`: Output<String>) {
        this.rewrite = value
    }

    /**
     * @param value how to match value in the Uri
     */
    @JvmName("qoebwvgeohwbfsqp")
    public suspend fun type(`value`: Output<Either<String, PathMatchType>>) {
        this.type = value
    }

    /**
     * @param value Uri path to match for request.
     */
    @JvmName("qksaetpoyqgxttvl")
    public suspend fun `value`(`value`: Output<String>) {
        this.`value` = value
    }

    /**
     * @param value replacement string for matched part of the Uri.
     */
    @JvmName("yhcfolmnmyokqykn")
    public suspend fun rewrite(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.rewrite = mapped
    }

    /**
     * @param value how to match value in the Uri
     */
    @JvmName("ltklkqrbkvyunjuf")
    public suspend fun type(`value`: Either<String, PathMatchType>) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value how to match value in the Uri
     */
    @JvmName("yihqjfnxbrdcuqxs")
    public fun type(`value`: String) {
        val toBeMapped = Either.ofLeft<String, PathMatchType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value how to match value in the Uri
     */
    @JvmName("aqbfivcbnnwrderj")
    public fun type(`value`: PathMatchType) {
        val toBeMapped = Either.ofRight<String, PathMatchType>(value)
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value Uri path to match for request.
     */
    @JvmName("qbhdaxquvwplydfk")
    public suspend fun `value`(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.`value` = mapped
    }

    internal fun build(): HttpRouteMatchPathArgs = HttpRouteMatchPathArgs(
        rewrite = rewrite,
        type = type ?: throw PulumiNullFieldException("type"),
        `value` = `value` ?: throw PulumiNullFieldException("value"),
    )
}
